<?php
/*
	The Account class handles all users actions and permissions checking.
*/

class Account extends MY_controller
{
	public $data = array();

	public function __construct()
	{
		parent::__construct();
		$this->data['page_path'] = strtolower(__CLASS__);
		$this->isUser();
		$this->isBanned();
	}

	private function isBanned ()
	{
		if ($this->data['userdata']['account_status'] == 2) // 2 = banned
		{
			if (strtolower($this->uri->segment(2)) != 'banned')
			{
				redirect(base_url($this->data['page_path'].'/banned'));
			}
		}
	}

	private function isUser ()
	{
		$usertoken = $this->session->token;

		if ($usertoken == '')
		{
			$this->session->unset_userdata('token');
			redirect(base_url('login'));
		}
		else
		{
			// get the user data from users tabel
	        $q = $this->cms_model->select('users',array('user_token'=>$usertoken,'user_verified'=>1));
	        if ($q->num_rows() == 1)
	        {
	            $a = $q->result_array();
	            $this->data['userdata'] = $a[0];

	            // get the user data from usersmata tabel
				$sel = $this->cms_model->select('usersmeta',array('user_id'=>$a[0]['id']));
				$r = $sel->result_array();

				foreach ($r as $k => $row)
				{
					$this->data['userdata'][$row['user_option']] = $row['user_value'];
				}
	        }
	        else
	        {
	        	$this->session->unset_userdata('token');
	        	redirect(base_url('login'));
	        }
		}
	}

	public function index ()
	{
		$this->data['title'] = langLine('notifAccount.index.span.1', false)." ".$this->data['userdata']['username']." !";
		$user_id = $this->data['userdata']['id'];

		$formated_duration = 'P30D'; // 30 days (default)
		$duration = '30'; // 30 days (default)
		$duration = $this->input->get('d')? $this->input->get('d', true) : $duration;

		if (intval($duration))
		{
			$formated_duration = "P".intval($duration)."D";
			// Get All links, Views, Earnings, Browsers, Operating Systems
			// counting links & links' views (30 days)
			$total_links = $this->db->select("COUNT(id) AS count")
												->where([
													'created >=' => get_datetime_from_now($formated_duration),
													'user_id' => $user_id,
												])
												->get('links')
												->first_row()
												->count;

			$total_banned_links = $this->db->select("COUNT(id) AS count")
												->where([
													'status' => 0,
													'created >=' => get_datetime_from_now($formated_duration),
													'user_id' => $user_id,
												])
												->get('links')
												->first_row()
												->count;

			$total_links_views = $this->db->select("SUM(views) AS count")
												->where([
													'created >=' => get_datetime_from_now($formated_duration),
													'user_id' => $user_id,
												])
												->get('stats')
												->first_row()
												->count;
			$total_links_earnings = $this->db->select("SUM(earnings) AS count")
												->where([
													'created >=' => get_datetime_from_now($formated_duration),
													'user_id' => $user_id,
												])
												->get('stats')
												->first_row()
												->count;

			// Top 10 countries (30 days).
			$top_countries = $this->db->select_sum('stats.views', 'total_views')
									->select_sum('stats.earnings', 'earnings')
									->select("stats.country_id, countries.name, countries.code")
									->from('stats')
									->join('countries', "countries.id=stats.country_id", 'inner')
									->where([
										'stats.created >=' => get_datetime_from_now($formated_duration),
										'stats.user_id' => $user_id
									])
									->group_by('stats.country_id')
									->order_by('total_views', 'DESC')
									->limit(10)->get()->result_object();

			$view_per_geo = $this->db->select_sum('stats.views', 'total_views')
									->select_sum('stats.earnings', 'earnings')
									->select("stats.country_id, countries.name, countries.code")
									->from('stats')
									->join('countries', "countries.id=stats.country_id", 'inner')
									->where([
										'stats.created >=' => get_datetime_from_now($formated_duration),
										'stats.user_id' => $user_id
									])
									->group_by('stats.country_id')
									->order_by('total_views', 'DESC')
									->get()->result_object();

			// Views line graph (30 days)
			$views_over_time = $this->db->select("COUNT(views) AS total_views, created")
										->select_sum('stats.earnings', 'total_earnings')
										->where([
											'created >=' => get_datetime_from_now($formated_duration),
											'user_id' => $user_id
										])
										->group_by('created')
										->order_by('created', 'ASC')
										->get('stats')
										->result_object();

			// Count Browsers, Devices, OS (30 days)
			$top_browsers = $this->db->select("COUNT(id) AS total_visitors, browser")
										->where([
											'created >=' => get_datetime_from_now($formated_duration),
											'user_id' => $user_id
										])
										->group_by('browser')
										->order_by('total_visitors', 'DESC')
										->get('stats')
										->result_object();

			$top_os = $this->db->select("COUNT(id) AS total_visitors, os")
										->where([
											'created >=' => get_datetime_from_now($formated_duration),
											'user_id' => $user_id
										])
										->group_by('os')
										->order_by('total_visitors', 'DESC')
										->get('stats')
										->result_object();
		}

		// Fetsh all stats
		if ($this->input->get('d', true) === 'all')
		{
			$total_links = $this->db->select("COUNT(id) AS count")
												->where([
													'user_id' => $user_id,
												])
												->get('links')
												->first_row()
												->count;

			$total_banned_links = $this->db->select("COUNT(id) AS count")
												->where([
													'status' => 0,
													'user_id' => $user_id,
												])
												->get('links')
												->first_row()
												->count;

			$total_links_views = $this->db->select("SUM(views) AS count")
												->where([
													'user_id' => $user_id,
												])
												->get('stats')
												->first_row()
												->count;

			$total_links_earnings = $this->db->select("SUM(earnings) AS count")
												->where([
													'user_id' => $user_id,
												])
												->get('stats')
												->first_row()
												->count;

			// Top 10 countries (30 days).
			$top_countries = $this->db->select_sum('stats.views', 'total_views')
									->select_sum('stats.earnings', 'earnings')
									->select("stats.country_id, countries.name, countries.code")
									->from('stats')
									->join('countries', "countries.id=stats.country_id", 'inner')
									->where([
										'stats.user_id' => $user_id
									])
									->group_by('stats.country_id')
									->order_by('total_views', 'DESC')
									->limit(10)->get()->result_object();

			$view_per_geo = $this->db->select_sum('stats.views', 'total_views')
									->select_sum('stats.earnings', 'earnings')
									->select("stats.country_id, countries.name, countries.code")
									->from('stats')
									->join('countries', "countries.id=stats.country_id", 'inner')
									->where([
										'stats.user_id' => $user_id
									])
									->group_by('stats.country_id')
									->order_by('total_views', 'DESC')
									->get()->result_object();

			// Views line graph (30 days)
			$views_over_time = $this->db->select("COUNT(views) AS total_views, created")
										->select_sum('stats.earnings', 'total_earnings')
										->where([
											'user_id' => $user_id
										])
										->group_by('created')
										->order_by('created', 'ASC')
										->get('stats')
										->result_object();

			// Count Browsers, Devices, OS (30 days)
			$top_browsers = $this->db->select("COUNT(id) AS total_visitors, browser")
										->where([
											'user_id' => $user_id
										])
										->group_by('browser')
										->order_by('total_visitors', 'DESC')
										->get('stats')
										->result_object();

			$top_os = $this->db->select("COUNT(id) AS total_visitors, os")
										->where([
											'user_id' => $user_id
										])
										->group_by('os')
										->order_by('total_visitors', 'DESC')
										->get('stats')
										->result_object();
		}

		$this->data['total_links'] = $total_links;
		$this->data['total_banned_links'] = $total_banned_links;
		$this->data['total_links_views'] = $total_links_views;
		$this->data['total_links_earnings'] = $total_links_earnings;
		$this->data['top_countries'] = $top_countries;
		$this->data['view_per_geo'] = $view_per_geo;
		$this->data['views_over_time'] = $views_over_time;
		$this->data['top_browsers'] = $top_browsers;
		$this->data['top_os'] = $top_os;

		$this->data['duration'] = $duration;

		$this->load->view("templates/header",$this->data);
		$this->data['sidebar'] = $this->load->view("templates/user_sidebar",$this->data,TRUE);
		$this->load->view("pages/user_account/dashboard",$this->data);
		$this->load->view("templates/footer",$this->data);
	}

	public function dashboard ()
	{
		$this->index();
	}

	public function profile()
	{
		$this->data['title'] = langLine('notifAccount.profile.span.1', false);

		$this->load->view("templates/header",$this->data);
		$this->data['sidebar'] = $this->load->view("templates/user_sidebar",$this->data,TRUE);
		$this->load->view("pages/user_account/profile",$this->data);
		$this->load->view("templates/footer",$this->data);
	}

	public function banned ()
	{
		if ($this->data['userdata']['account_status'] == 2) // 2 = banned
		{
			$this->data['title'] = langLine('notifAccount.banned.title', false);


			$this->load->view("templates/header",$this->data);
			$this->data['sidebar'] = $this->load->view("templates/user_sidebar",$this->data,TRUE);
			$this->load->view("pages/user_account/Banned",$this->data);
			$this->load->view("templates/footer",$this->data);
		}
		else
		{
			redirect(base_url($this->data['page_path']));
		}
	}

	public function addlinks ()
	{
			$this->data['title'] = langLine('notifAccount.addlinks.title', false);


			$this->load->view("templates/header",$this->data);
			$this->data['sidebar'] = $this->load->view("templates/user_sidebar",$this->data,TRUE);
			$this->load->view("pages/user_account/addlinks",$this->data);
			$this->load->view("templates/footer",$this->data);
	}

	public function mylinks ($v='',$p='')
	{
		$user_id = $this->data['userdata']['id'];

		if ($this->input->get('s'))
		{
			$str = trim(strip_tags($this->input->get('s',TRUE)));
			$this->data['string'] = $str;
			$cols = ['title', 'slug'];
			$string = '?s='.$str;
		}
		else
		{
			$string = '';
		}

		if ($v == '' or $p == '')
		{
			redirect(base_url($this->data['page_path'].'/mylinks/p/1'.$string));
		}

		$p = (intval($p) <= 0)? redirect(base_url($this->data['page_path'].'/mylinks/p/1')) : intval($p) ;
		$length = 15; // number of link per page
		$start = ceil(($p - 1) * $length);




		if (isset($str))
		{
			if (version_compare(PHP_VERSION, '7.4', '>='))
			    $imploded = implode(',', $cols);
			else
			    $imploded = implode($cols, ',');

			$links = $this->db->select('links.id, links.title, links.slug, links.domain, links.status, links.created, links.url, links.direct_redirection')
							->select_sum('stats.views', 'total_views')
							->select_sum('stats.earnings', 'total_earnings')
							->from('links')
							->join('stats', 'stats.link_id = links.id', 'left')
							->where('links.user_id', $user_id)
							->where("MATCH($imploded) AGAINST('$str' IN BOOLEAN MODE)", NULL, FALSE)
							->group_by('links.id')
							->order_by('links.created', 'DESC')
							->limit($length, $start)
							->get();

			$total_items = $this->db->select('COUNT(id) as total_links')
									->where('user_id', $user_id)
									->where("MATCH($imploded) AGAINST('$str' IN BOOLEAN MODE)", NULL, FALSE)
									->get('links')
									->first_row()
									->total_links;
		}
		else
		{
			$links = $this->db->select('links.id, links.title, links.slug, links.domain, links.status, links.created, links.url, links.direct_redirection')
							->select_sum('stats.views', 'total_views')
							->select_sum('stats.earnings', 'total_earnings')
							->from('links')
							->join('stats', 'stats.link_id = links.id', 'left')
							->where('links.user_id', $user_id)
							->group_by('links.id')
							->order_by('links.created', 'DESC')
							->limit($length, $start)
							->get();

			$total_items = $this->db->select('COUNT(id) as total_links')
									->where('user_id', $user_id)
									->get('links')
									->first_row()
									->total_links;
		}


		// for pagination.
		$this->data['total_items'] = $total_items;
		$this->data['num_per_page'] = $length;
		$all_pages = ceil($total_items / $length);
		$this->data['all_pages'] = $all_pages;
		$this->data['p'] = $p;

		$this->data['links'] = $links;

		$this->data['title'] = langLine('notifAccount.mylinks.title', false);

		$this->load->view("templates/header",$this->data);
		$this->data['sidebar'] = $this->load->view("templates/user_sidebar",$this->data,TRUE);
		$this->load->view("pages/user_account/mylinks",$this->data);
		$this->load->view("templates/footer",$this->data);
	}

	public function withdrawal()
	{
		$user_id = $this->data['userdata']['id'];
		$this->data['title'] = langLine('account.withdrawal.title', false);
		$this->data['withdrawal_methods'] = $this->db->select('*')
											->where(['status' => 1])
											->get('withdrawal_methods')->result_object();

		$this->data['withdrawal_requests'] = $this->db->select('withdraw_reqs.id, withdraw_reqs.withdrawal_account, withdraw_reqs.status, withdraw_reqs.amount, withdrawal_methods.name AS method')
											->from('withdrawal_methods')
											->join('withdraw_reqs', 'withdraw_reqs.withdrawal_method_id = withdrawal_methods.id', 'inner')
											->where([
												'withdraw_reqs.status' => 0,
												'withdraw_reqs.user_id' => $user_id
											])
											->order_by('withdraw_reqs.created', 'DESC')
											->get()->result_object();

		$this->data['withdrawal_requests_history'] = $this->db->select('withdraw_reqs.id, withdraw_reqs.withdrawal_account, withdraw_reqs.status, withdraw_reqs.amount, withdrawal_methods.name AS method, withdraw_reqs.created')
											->from('withdrawal_methods')
											->join('withdraw_reqs', 'withdraw_reqs.withdrawal_method_id = withdrawal_methods.id', 'inner')
											->where([
												'withdraw_reqs.status !=' => 0,
												'withdraw_reqs.user_id' => $user_id
											])
											->order_by('withdraw_reqs.created', 'DESC')
											->get()->result_object();


		$this->load->view("templates/header", $this->data);
		$this->data['sidebar'] = $this->load->view("templates/user_sidebar", $this->data,TRUE);
		$this->load->view("pages/user_account/withdrawal", $this->data);
		$this->load->view("templates/footer", $this->data);
	}

	public function developers_api()
	{
		$this->data['title'] = langLine('account.sidebar.span.8', false);
		$user = $this->db->where('id', $this->data['userdata']['id'])->get('users')->first_row();
		$this->data['user'] = $user;

		$this->load->view("templates/header", $this->data);
		$this->data['sidebar'] = $this->load->view("templates/user_sidebar", $this->data,TRUE);
		$this->load->view("pages/user_account/developers_api", $this->data);
		$this->load->view("templates/footer", $this->data);
	}

	public function refresh_api_token()
	{
		$new_token = sha1(time());
		$old_token = $this->data['userdata']['user_token'];

		$this->db->where('user_token', $old_token)->update(_t('users'), [
			'user_token' => $new_token
		]);

		echo json_encode(['token' => $new_token]);
	}

	public function ajax ($var="")
	{
		/*==================== Create withdrawal req =========================*/
		if ($this->input->post('tab',TRUE) == 3)
		{
			$withdrawal_method_id = intval($this->input->post('withdrawal_method', true));
			$withdrawal_account = $this->input->post('withdrawal_account', true);
			$amount = abs((float)$this->input->post('amount', true));

			$method = $this->db->select('*')->where([
				'id' => $withdrawal_method_id,
				'status' => 1, // 1=active
			])->get('withdrawal_methods')->first_row();

			// check if the selected method is active first.
			if (isset($method->status) && $method->status)
			{
				// valid a earnings mount.
				if ($amount > $this->data['userdata']['earnings'])
				{
					$err = langLine('notifAccount.withdraw.span.32', false);
				}
				// check minimum amount for withdrawal method.
				else if ($amount < $method->min_amount)
				{
					$err = langLine('notifAccount.withdraw.span.33', false);
				}
				else
				{
					// make sure user's earnings is persistent
					$this->db->trans_start();

					// create a new withdraw request
					$this->db->insert('withdraw_reqs', [
						'user_id' => $this->data['userdata']['id'],
						'withdrawal_method_id' => $withdrawal_method_id,
						'withdrawal_account' => $withdrawal_account,
						'amount' => $amount,
						'created' => date('Y-m-d H:i:s')
					]);

					// updating user's earnings.
					$this->db->where('id', $this->data['userdata']['id'])
						->update('users', [
							'earnings' => (float)$this->data['userdata']['earnings'] - $amount
						]);

					$this->db->trans_complete();

					if ($this->db->trans_status())
					{
						$ok = langLine('notifAccount.withdraw.span.29', false);
						$ok .= "<script>
							setTimeout(() => {
								location.reload()
							}, 2000)
						</script>";
					}
					else
					{
						$err = langLine('notifAccount.withdraw.span.31', false);
					}
				}
			}
			else
			{
				$err = langLine('notifAccount.withdraw.span.30', false);
			}

		} // end if of update data of user


		/*======================== delete withdrawal req =============================*/
		if ($this->input->post('delete_withdrawal_req', TRUE))
		{
			header('Content-Type: application/json');

			$req_id = intval($this->input->post('req_id', TRUE));

			$req = $this->db->select('withdraw_reqs.id, withdraw_reqs.user_id, withdraw_reqs.withdrawal_account, withdraw_reqs.status, withdraw_reqs.amount, withdrawal_methods.name AS method')
											->from('withdrawal_methods')
											->join('withdraw_reqs', 'withdraw_reqs.withdrawal_method_id = withdrawal_methods.id', 'inner')
											->where([
												'withdraw_reqs.status' => 0,
												'withdraw_reqs.id' => $req_id
											])
											->get()
											->first_row();
			if ($req)
			{
				// do the deletion here.
				$this->db->trans_start();

				$this->db->delete('withdraw_reqs', ['id' => $req_id]);
				// update user's earnings too.
				$this->db->where('id', $req->user_id)->update('users', [
					'earnings' => (float)$this->data['userdata']['earnings'] + (float)$req->amount
				]);

				$this->db->trans_complete();
				if ($this->db->trans_status())
				{
					echo json_encode([
						'deleted' => true
					]);
				}
				else
				{
					echo json_encode([
						'deleted' => false
					]);
				}
			}
			else
			{
				echo json_encode([
					'deleted' => false
				]);
			}

			return; // to exit
		} // end if of update data of user

		/*======================== Change user data =============================*/
		if ($this->input->post('tab',TRUE) == 1)
		{
			$mess = $this->cms_model->userProfileUpdate();
			if ($mess[0] == 'ok')
			{
				$ok = $mess[1];
			}
			else
			{
				$err = $mess[1];
			}

		} // end if of update data of user

		/*======================== Change password of user =============================*/
		if ($this->input->post('tab',TRUE) == 2)
		{
			if (is_demo())
			{
				$ok = "Oops, This Action is not allowed on the Demo!";
			}
			else
			{
				$old_pass 	= trim(strip_tags($this->input->post('old-pass',TRUE)));
				$new_pass 	= trim(strip_tags($this->input->post('new-pass',TRUE)));
				$conf_pass 	= trim(strip_tags($this->input->post('conf-new-pass',TRUE)));

				if (!recaptcha())
				{
					$err = langLine('notifAccount.password.span.1', false);
				}
				else if ($old_pass == '' or $new_pass == '' or $conf_pass == '')
				{
					$err = langLine('notifAccount.password.span.2', false);
				}
				else if (!password_verify($old_pass,$this->data['userdata']['password']))
				{
					$err = langLine('notifAccount.password.span.3', false);
				}
				else if ($new_pass != $conf_pass)
				{
					$err = langLine('notifAccount.password.span.4', false);
				}
				else
				{
					$set['password'] = password_hash($new_pass,PASSWORD_DEFAULT);
					$where = array('user_token'=>$this->data['userdata']['user_token']);

					$up = $this->cms_model->update('users',$set,$where);

					if ($up)
					{
						$ok = langLine('notifAccount.password.span.5', false);
						$ok .= "
						<script type='text/javascript'>
							$('input[name=old-pass]').val('');
							$('input[name=new-pass]').val('');
							$('input[name=conf-new-pass]').val('');
						</script>
						";
					}
					else
					{
						$err = langLine('notifAccount.password.span.6', false);
					}
				}

			}

			$script = "
				<script type='text/javascript'>
					$(document).ready(function (){
						// If recaptcha object exists, refresh it
						setTimeout(function (){
							grecaptcha.reset();
						},2000);
					});
				</script>
			";

			if (isset($err))
			{
				$err .= $script;
			}
			else
			{
				$ok .= $script;
			}
		} // end repass

		/*======================= Upload profile image ===========================*/
		if ($this->input->post('tab') == 'img')
		{
	        $config['upload_path']          = './uploads/users/profile-images';
	        $config['allowed_types']        = 'gif|jpg|png|jpeg';
	        $config['max_size']             = 1024; // 1 MB
	        $config['max_width']            = 1024;
	        $config['max_height']           = 1024;
	        $config['file_name']			= md5($this->data['userdata']['user_token']).".png";
	        $config['overwrite'] 			= TRUE;

	        $this->load->library('upload',$config);

			if (!$this->upload->do_upload('img'))
			{
				$err = $this->upload->display_errors();
			}
			else
			{
				$img_data = $this->upload->data();

			    $conf['image_library'] 	= 'gd2';
			    $conf['source_image'] 	= './uploads/users/profile-images/'.$img_data['file_name'];
			    $conf['create_thumb'] 	= FALSE;
			    $conf['maintain_ratio'] = TRUE;
			    $conf['width']     		= 170;
			    $conf['height']   		= 170;
			    $conf['quality']		= 100;

			    $this->load->library('image_lib',$conf);

			    if (!$this->image_lib->resize())
			    {
			    	$err = $this->image_lib->display_errors();
			    }
			    else
			    {
			    	$ok = langLine('notifAccount.profileImage.span.1', false);
			    }
			}
		}

		/*======================== Add a new link =============================*/

		if ($this->input->post('action') == 'addLink')
		{
			$title 		= trim(strip_tags($this->input->post('title',TRUE)));
			$url 		= trim(strip_tags($this->input->post('url',TRUE)));
			$type 		= abs(intval($this->input->post('type',TRUE)));
			$domain		= intval($this->input->post('domain', TRUE));
			$direct		= intval($this->input->post('direct-redirection', TRUE));
			$keywords		= $this->input->post('keywords', TRUE);
			$description	= $this->input->post('description', TRUE);
			$slug		= $this->input->post('slug', TRUE);

			// Generate slug if empty.
			$slug = ($slug)? $slug : get_slug();

			$newLinks = '';
			$ex  = explode("\n",$url);

			// if there are a one link
			if (count($ex) == 1 && $type == 0)
			{
				if (!recaptcha())
				{
					$err = langLine('notifAccount.newLink.span.1', false);
				}
				else if ($title == '')
				{
					$err = langLine('notifAccount.newLink.span.2', false);
				}
				else if (mb_strlen($title) > 100)
				{
					$err = langLine('notifAccount.newLink.span.3', false);
				}
				else if ($url == '')
				{
					$err = langLine('notifAccount.newLink.span.4', false);
				}
				else if (mb_strlen($url) > 500)
				{
					$err = langLine('notifAccount.newLink.span.5', false);
				}
				else if (!is_url($url))
				{
					$err = langLine('notifAccount.newLink.span.6', false);
				}
				else if (is_forbiden_url($url))
				{
					$err = langLine('notifAccount.newLink.span.7', false);
				}
				else if (!is_valid_slug_format($slug))
				{
					$err = langLine('notifAccount.newLink.span.20', false);
				}
				else if (!is_available_slug($slug))
				{
					$err = langLine('notifAccount.newLink.span.21', false);
				}
				else
				{
					$newLinks = get_domains($domain).$slug;

					$d['user_id'] 	= $this->data['userdata']['id'];
					$d['title'] 		= $title;
					$d['url'] 			= encode($url);
					$d['slug'] 			= $slug;
					$d['domain']		= $domain;
					$d['status'] 		= 1;
					$d['direct_redirection'] = $direct;
					$d['keywords'] = $keywords;
					$d['description'] = $description;

					$insert = $this->cms_model->insert('links',$d);

					if ($insert)
					{
						$ok = langLine('notifAccount.newLink.span.8', false);
					}
					else
					{
						$err = langLine('notifAccount.newLink.span.9', false);
					}
				}
			}

			$script = "
				<script type='text/javascript'>
					$(document).ready(function (){
						// If recaptcha object exists, refresh it
						setTimeout(function (){
							grecaptcha.reset(recaptcha1);
							grecaptcha.reset(recaptcha2);
						},2000);
					});
				</script>
			";

			$script2 = "
				<script type='text/javascript'>
				$(document).ready(function (){
					$('#boxToAddLink').slideUp(function (){
						$('#urls textarea').html('".$newLinks."');
						$('#urls').slideDown();
					});
					$('#boxToAddLink input[type=text]').val('');
					$('#boxToAddLink textarea').val('');
				});
				</script>
			";

			if (isset($err))
			{
				$err .= $script;
			}
			else if (isset($ok))
			{
				$ok .= $script."<br>".$script2;
			}

		}

		/*======================== Delete link by user ===========================*/

		if ($this->input->post('deleteLink'))
		{
			$id = abs(intval($this->input->post('id',TRUE)));

			$w['id'] = $id;
			$w['user_id'] = $this->data['userdata']['id'];

			$del = $this->cms_model->delete('links',$w);

			if ($del)
			{
				echo langLine('notifAccount.deleteLink.span.1', false);
			}
			else
			{
				echo langLine('notifAccount.deleteLink.span.2', false);
			}
		}

		/*==================== block the user his account ========================*/

		if ($this->input->post('blockAccount'))
		{
			if (is_demo())
			{
				$ok = "Oops, This Action is not allowed on the Demo!";
			}
			else
			{
				$pass = trim(strip_tags($this->input->post('pass',TRUE)));

				$w['user_token'] = $this->data['userdata']['user_token'];
				$w['user_status'] = 0;
				$s_user = $this->cms_model->select('users',$w);

				if ($s_user->num_rows() == 1)
				{
					$row = $s_user->row_array();

					if (password_verify($pass,$row['password']))
					{
						$set['account_status'] = 1; // inactive account
						$where['user_token'] = $row['user_token'];
						$up = $this->cms_model->update('users',$set,$where);

						if ($up)
						{
							$script = "
							<script>
							setTimeout(function (){
								window.location.href='".base_url('logout')."';
							},5000);
							</script>
							";
							$ok = langLine('notifAccount.blockAccount.span.1', false).' '.$script;
						}
						else
						{
							$err = langLine('notifAccount.blockAccount.span.2', false);
						}
					}
					else
					{
						$err = langLine('notifAccount.blockAccount.span.3', false);
					}
				}
				else
				{
					$err = langLine('notifAccount.blockAccount.span.4', false);
				}

			}


			if (isset($err) && $err != '')
			{
				$err .= "
				<script>
					$('#deleteAccountByUser').fadeIn();
				</script>
				";
			}
		}

		/*======================== Echo the messages =============================*/

		if (isset($err) && $err != '')
		{
			echo "<div class='alert alert-warning'>".$err."</div>";
		}
		else if (isset($ok) && $ok != '')
		{
			echo "<div class='alert alert-success'><i class='fa fa-lg fa-check'></i> ".$ok."</div>";
		}

	} // end ajax function
}


?>
