<?php

class Api extends MY_controller
{
	public function __construct()
	{
		parent::__construct();
	}

	public function index()
	{
		header('Content-Type: application/json');

		if ($this->input->get())
		{
			$title = $this->input->get('title', true);
			$token = $this->input->get('token', true);
			$url = $this->input->get('url', true);
			$domain = intval($this->input->get('domain', true));

			$direct_redirection = intval($this->input->get('direct', true));
			$custom_slug = $this->input->get('slug', true);
			$seo_keywords = $this->input->get('seo-keywords', true);
			$seo_desc = $this->input->get('seo-desc', true);


			$user = $this->db->where('user_token', $token)->get('users')->first_row();
			$all_domains = get_all_domains();
			$slug = $custom_slug? $custom_slug : get_slug();

			// set a default title.
			$title = $title ? $title : "api-".time();

			$all_domains[] = get_main_domain();

			if (!$user)
			{
				// invalid domains (domain not found)
				return die(json_encode([
					'status' => 'error',
					'message' => 'Invalid User Token',
				]));
			}
			elseif (!isset($all_domains[$domain]))
			{
				// invalid domains (domain not found)
				return die(json_encode([
					'status' => 'error',
					'message' => 'invalid domain',
				]));
			}
			else if (!is_valid_slug_format($slug))
			{
				return die(json_encode([
					'status' => 'error',
					'message' => 'Invalid slug format!',
				]));
			}
			else if (!is_available_slug($slug))
			{
				return die(json_encode([
					'status' => 'error',
					'message' => 'Slug already used, use another one!',
				]));
			}
			else if (!filter_var($url, FILTER_VALIDATE_URL))
			{
				// invalid url
				return die(json_encode([
					'status' => 'error',
					'message' => 'invalid URL',
				]));
			}
			else if (is_forbiden_url($url))
			{
				// forbiden url.
				return die(json_encode([
					'status' => 'error',
					'message' => 'This URL is forbiden.',
				]));
			}
			else
			{
				$link = $this->db->insert('links', [
					'user_id' => 	$user->id,
					'title' => 		$title,
					'url' => 		$url,
					'slug' => 		$slug,
					'domain' => 	$domain,
					'status' => 	1,
					'direct_redirection' => $direct_redirection,
					'keywords' => 		$seo_keywords,
					'description' => 	$seo_desc
				]);

				if ($link)
				{
					return die(json_encode([
						'status' => 'success',
						'message' => 'Done successfully',
						'shortened_url' => get_domains($domain)."{$slug}"
					], JSON_UNESCAPED_SLASHES));
				}
			}
		}
	}
}

?>
