<?php
use Sinergi\BrowserDetector\Browser;
use Sinergi\BrowserDetector\Device;
use Sinergi\BrowserDetector\Os;


class Go extends MY_controller
{
	private $data = array();

	public function __construct()
	{
		parent::__construct();
		$this->data['page_path'] = strtolower(__CLASS__);
	}

	public function index($slug='')
	{
		// Protect the main domain.
		main_domain_protection_shield();

		$this->data['showOriginalLink'] = false;

		$link = $this->db->where([
					'slug' => $slug,
					'status' => 1 // active link.
				])->get('links')->first_row();

		// Apply Direct Redirection.
		if (isset($link) && $link->direct_redirection == 1 && $link->status == 1)
		{
			//============= Updating Stats ===========
			$browser = new Browser();
			$device = new Device();
			$os = new Os();
			$link_user = get_user(intval($link->user_id));

			$w_insert = [
				'user_id' 	=> $link_user->id,
				'link_id' 	=> $link->id,
				'views' 	=> 1,
				'earnings' 	=> 0, // No earnings for Direct Redirection mode.
				'browser' 	=> $browser->getName(),
				'device' 	=> $device->getName(),
				'os' 		=> $os->getName(),
				'created' 	=> date('Y-m-d'),
				'ip'		=> get_client_ip()
			];
			$country_db = get_client_country_from_db();
			if ($country_db)
			{
				$w_insert['country_id'] = $country_db->country_id;
			}

			$this->db->insert('stats', $w_insert);
			return redirect($link->url);
		}

		// check the link is active & redirect and reCaptcha
		if ($this->input->post('get_link'))
		{
			$slug = $this->input->post('slug', true);
			$link = $this->db->where([
						'slug' => $slug,
						'status' => 1 // active link.
					])->get('links')->first_row();

			if (!isset($link->id))
			{
				// redirect to 404 page
				show_my_404();
			}
			else if (!recaptcha())
			{
				// refresh the page & leave a message.
				set_message('Invalid captcha, please try again!', 'danger');
				redirect(base_url($slug));
			}
			else
			{
				$this->data['showOriginalLink'] = true;

				// Skip visitors spamming per 1 ip.
				$total_visits = $this->db->select('COUNT(id) AS total_visits')
						->where([
							'link_id' 	=> $link->id,
							'ip' 		=> get_client_ip(),
							'created' 	=> date('Y-m-d'),
						])->get('stats')
						->first_row()
						->total_visits;

				// Do the visit registration.
				if ($total_visits < intval(get_config_item('ip_max_visits')))
				{
					//============= calculating link views & user's earnings ===========

					$linkdata = $this->db->where('slug', $slug)->get('links')->first_row('array');
					$userdata = $this->db->where('id', $linkdata['user_id'])->get('users')->first_row();

					if ($linkdata['status'] == 1 && !isset($t)) // link active
					{
						// calculating earnings for this click.
						$click_price = get_click_price();

						// update user's balance/earnings
						$this->db->set(['earnings' => $userdata->earnings + $click_price])
								->where(['id' => $linkdata['user_id']])
								->update('users');
					}

					//============= Updating Stats ===========
					$browser = new Browser();
					$device = new Device();
					$os = new Os();

					$w_insert = [
						'user_id' 	=> $userdata->id,
						'link_id' 	=> $linkdata['id'],
						'views' 	=> 1,
						'earnings' 	=> get_click_price(),
						'browser' 	=> $browser->getName(),
						'device' 	=> $device->getName(),
						'os' 		=> $os->getName(),
						'created' 	=> date('Y-m-d'),
						'ip'		=> get_client_ip()
					];
					$country_db = get_client_country_from_db();
					if ($country_db)
					{
						$w_insert['country_id'] = $country_db->country_id;
					}

					$this->db->insert('stats', $w_insert);
				}

			}
		}
		else
		{
			if (!$link)
			{
				show_my_404();
			}
		}


		$max_result = 10; // show 10 results
		$this->data['recentLinks'] = $this->db->select('title, slug, domain')
											->where('status', 1)
											->order_by('created', 'DESC')
											->get('links', $max_result)
											->result_object();

		$total_links = $this->db->select('COUNT(id) AS total_links')
								->where('status', 1)
								->get('links')
								->first_row()
								->total_links;

		$random_start = rand(1, $total_links) - $max_result;
		$random_start = $random_start <= 0 ? 1 : $random_start;

		$this->data['randomLinks'] = $this->db->select('title, slug, domain')
												->where('status', 1)
												->get('links', $max_result, $random_start)
												->result_object();

		$this->data['link'] = $link;
		$this->data['title'] = $link->title;

		$this->load->view('templates/go_header',$this->data);
		if (intval(get_config_item('go_page_style')) === 0)
			$this->load->view('pages/go_style_0',$this->data);
		else
			$this->load->view('pages/go_style_1',$this->data);
		$this->load->view('templates/footer',$this->data);
	}
}

?>
