<?php

use Doctrine\DBAL\DriverManager;
use GeoIp2\Database\Reader;


$CI =& get_instance();

function my_base_url($uri=null)
{
    $current_base_url = parse_url(base_url($uri));

    $base = (isset($current_base_url['port']))? $current_base_url['host'].":".$current_base_url['port'] : $current_base_url['host'];

    if (!is_main_domain($base))
    {
        return $current_base_url['scheme']."://".get_main_domain().$current_base_url['path'];
    }

    return base_url($uri);
}

function get_db()
{
    static $conn = null;
    if (!$conn)
    {
        $conn = DriverManager::getConnection([
            'dbname' => getenv('DB_NAME'),
            'user' => getenv('DB_USER'),
            'password' => getenv('DB_PASSWORD'),
            'host' => getenv('DB_HOSTNAME'),
            'driver' => 'pdo_mysql',
        ]);
    }

    return $conn;
}

function cache_hash()
{
    return md5('10-3-2023');
}

function is_demo()
{
    if (isset($_ENV['SITE_DEMO_MODE']) && ($_ENV['SITE_DEMO_MODE'] == '1' || $_ENV['SITE_DEMO_MODE'] == 'true'))
        return true;

    return false;
}

function show_my_404()
{
    global $CI;
    $data['title'] = langLine('theme.404.title', false);
    $data['heading'] = langLine('theme.404.title', false);
    $data['message'] = langLine('theme.404.message', false);

    // just to ensure the database is loaded.
    $CI =& get_instance();

    // set header here for SEO
    $CI->output->set_status_header('404');

    $CI->load->view('templates/header', $data);
    $CI->load->view('pages/404', $data);
    $CI->load->view('templates/footer', $data);
    $CI->output->_display();
    exit;
}

function _t($table_name)
{
    return getenv('DB_PREFIX').$table_name;
}

// Function to get the client IP address
function get_client_ip()
{
    $ipaddress = '';

    if (isset($_SERVER['HTTP_X_REAL_IP']) && $_SERVER['HTTP_X_REAL_IP'] != "")
        $ipaddress = $_SERVER['HTTP_X_REAL_IP'];
    else if (getenv('HTTP_CLIENT_IP'))
        $ipaddress = getenv('HTTP_CLIENT_IP');
    else if(getenv('HTTP_X_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_X_FORWARDED_FOR');
    else if(getenv('HTTP_X_FORWARDED'))
        $ipaddress = getenv('HTTP_X_FORWARDED');
    else if(getenv('HTTP_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_FORWARDED_FOR');
    else if(getenv('HTTP_FORWARDED'))
       $ipaddress = getenv('HTTP_FORWARDED');
    else if(getenv('REMOTE_ADDR'))
        $ipaddress = getenv('REMOTE_ADDR');
    else
        $ipaddress = 'UNKNOWN';
    return $ipaddress;
}

function get_all_account_status()
{
    return [
        0 => 'Active',
        1 => 'Inactive',
        2 => 'Banned',
    ];
}

function get_account_status($account_id, $badge=false)
{
    $all_statuses = get_all_account_status();
    $status = '';
    $status_badge = '';

    switch($account_id)
    {
        case 0:
            $status = $all_statuses[0];
            $status_badge = "<span class='badge label-success'>{$all_statuses[0]}</span>";
        break;
        case 1:
            $status = $all_statuses[1];
            $status_badge = "<span class='badge label-warning'>{$all_statuses[1]}</span>";
        break;
        case 2:
            $status = $all_statuses[2];
            $status_badge = "<span class='badge label-danger'>{$all_statuses[2]}</span>";
        break;
    }

    if ($badge)
        return $status_badge;
    return $status;
}

function get_lang_directions()
{
    return ['LTR', 'RTL'];
}

function get_all_statuses()
{
    return ['Inactive', 'Active'];
}

function get_all_yes_no_status()
{
    return ['No', 'Yes'];
}

function get_yes_no_status($status_id, $badge=false)
{
    $status = '';
    $status_badge = '';

    if ($status_id == 0){
        $status = "No";
        $status_badge = "<span class='badge label-secondary'>No</span>";
    } else {
        $status = "Yes";
        $status_badge = "<span class='badge label-success'>Yes</span>";
    }

    if ($badge)
        return $status_badge;
    else
        return $status;

}

function get_status($status_id, $badge=false)
{
    $status = '';
    $status_badge = '';

    if ($status_id == 0){
        $status = "Inactive";
        $status_badge = "<span class='badge label-warning'>Inactive</span>";
    } else {
        $status = "Active";
        $status_badge = "<span class='badge label-success'>Active</span>";
    }

    if ($badge)
        return $status_badge;
    else
        return $status;
}

function get_announcement_availabilities()
{
    return [
        'Global',
        'Users Only',
        'Visitors Only'
    ];
}

function get_announcement_availability($ann_id, $badge=false)
{
    $all_avai = get_announcement_availabilities();
    $availability = '';
    $availability_badge = '';

    switch($ann_id)
    {
        case 0:
            $availability = $all_avai[0];
            $availability_badge = "<span class='badge label-warning'>{$all_avai[0]}</span>";
            break;
        case 1:
            $availability = $all_avai[1];
            $availability_badge = "<span class='badge label-success'>{$all_avai[1]}</span>";
            break;
        case 2:
            $availability = $all_avai[2];
            $availability_badge = "<span class='badge label-info'>{$all_avai[2]}</span>";
            break;
    }

    if ($badge)
        return $availability_badge;
    return $availability;
}

function get_all_announcements($availability=-1)
{
    global $CI;

    // just to ensure the database is loaded.
    $CI =& get_instance();

    $query = $CI->db->select('*');

    if ($availability != -1)
    {
        $query->where('availability', intval($availability));
    }

    return $query->where('status', 1)->get('announcements')->result_object();

}

function get_country_flag($code)
{
    return "<i class='flag-icon flag-icon-$code' ></i>";
}

function get_client_country()
{
    try
    {
        $reader = new Reader(APPPATH.'../uploads/GeoLite2-City.mmdb');
        $record = $reader->city(get_client_ip());
        return $record->country;
    } catch (GeoIp2\Exception\AddressNotFoundException $e) {
        return;
    }
}

function get_client_country_from_db()
{
    global $CI;
    try
    {
        $reader = new Reader(APPPATH.'../uploads/GeoLite2-City.mmdb');
        $record = $reader->city(get_client_ip());
        $country = $record->country;
        // getting CPC (cost per click) for a spesific country
        $query = $CI->db->select('*')
                ->from('countries')
                ->join('publisher_rates', 'publisher_rates.country_id = countries.id', 'inner')
                ->where(['countries.code' => strtolower($country->isoCode)])
                ->get();
        $countries_rates = $query->first_row();

        if ($countries_rates)
        {
            return $countries_rates;
        }
    } catch (GeoIp2\Exception\AddressNotFoundException $e) {
        // do nothing.
    }
    return;
}

function get_click_price()
{
    global $CI;
    try
    {
        $reader = new Reader(APPPATH.'../uploads/GeoLite2-City.mmdb');
        $record = $reader->city(get_client_ip());
        $country = $record->country;
        // getting CPC (cost per click) for a spesific country
        $query = $CI->db->select('*')
                ->from('countries')
                ->join('publisher_rates', 'publisher_rates.country_id = countries.id', 'inner')
                ->where(['countries.code' => strtolower($country->isoCode)])
                ->get();
        $countries_rates = $query->first_row();

        if ($countries_rates)
        {
            return (float)($countries_rates->price / 1000);
        }
    } catch (GeoIp2\Exception\AddressNotFoundException $e) {
        // do nothing.
    }
    // default pricing.
    return (float)(get_config_item('world_wide') / 1000);
}

// for resolve withrowal reqs status
function get_req_status($num)
{
    switch($num)
    {
        case '0': return "Pending";
        case '1': return "Approved";
        case '2': return "Completed";
        case '3': return "Cancelled";
        case '4': return "Returned";
    }
}

function get_all_req_statuses()
{
    return [
        0 => 'Pending',
        1 => 'Approved',
        2 => 'Completed',
        3 => 'Cancelled',
        4 => 'Returned',
    ];
}

function get_placements_enum($id=null)
{
    $placements = [
        0 => 'HOME_UP',
        1 => 'HOME_DOWN',
        2 => 'LOGIN_&_REGISTER',
        3 => 'REDIRECT_PAGE_UP',
        4 => 'REDIRECT_PAGE_DOWN',
        5 => 'REDIRECT_PAGE_LEFT',
        6 => 'REDIRECT_PAGE_RIGHT',
        7 => 'USER_UP',
        8 => 'USER_DOWN',
        9 => 'USER_NAVBAR'
    ];

    if ($id != null)
        return $placements[intval($id)];

    return $placements;
}

function get_ad_placement_by_name($placement_name, $raw=false)
{
    global $CI;
    $CI =& get_instance();
    $all_placements = get_placements_enum();

    foreach ($all_placements as $key => $value)
    {
        if ($placement_name == $value)
        {
            // return a placement from database.
            $ad = $CI->db->where([
                'placement' => $key,
                'status'    => 1,
            ])->order_by('id', 'RANDOM')->get('ads')->first_row();

            if ($ad)
                return ($raw)? $ad : $ad->code;
        }
    }

    return null;
}

function get_currency()
{
    $currency = explode(',', get_config_item('currency'));
    return ['name' => $currency[0], 'symbol' => $currency[1]];
}

function http_redirect($path)
{
    return header("location: " . base_url($path));
}

function set_message($message=null, $type='warning')
{
    global $ALERT_MESSAGES;

    if (is_string($message))
    {
        $message = ['content' => $message, 'type' => $type];
        $ALERT_MESSAGES[] = $message;
    }
    // create a cookie.
    setcookie('ALERT_MESSAGES', json_encode($ALERT_MESSAGES), time()+30*24*3600, "/");
}

function get_messages($text=false)
{
    $messages = isset($_COOKIE['ALERT_MESSAGES'])? json_decode($_COOKIE['ALERT_MESSAGES'], true) : [];
    $messages = is_array($messages)? $messages : [];
    $result = $text ? '' : [];

    foreach ($messages as $key => $message) {
        if ($text)
            $result .= "<div class='alert alert-".$message['type']."'>".$message['content']."</div>";
        else
            $result[] = $message;
    }
    // Deleting the cookie.
    setcookie('ALERT_MESSAGES', '', time()-3000, "/");
    return $result;
}

function labelNotification()
{
    global $CI;
    // check the news & update
    $string = "";
    $update = 0;
    $news = 0;

    $s = $CI->cms_model->select('updates');
    if ($s->num_rows() == 1)
       $update = 1;

    $s2 = $CI->cms_model->select('news');
    if ($s2->num_rows())
        $news = 1;

    if ($update)
        $string .= "<span class='label label-danger pull-right'>Update</span>";

    if ($news && config_item('viewed_news') == 0)
        $string .= "<span class='label label-success pull-right'>News</span>";

    return $string;
}


function count_user_links($id=0)
{
    global $CI;
    return (int)$CI->db->select('COUNT(id) AS total_links')->where('user_id', $id)->get('links')->first_row()->total_links;
}

function count_user_views($id=0)
{
    global $CI;
    return (int)$CI->db->select('SUM(views) AS total_views')->where('user_id', $id)->get('stats')->first_row()->total_views;
}

function langLine($key, $echo = true, $replace = [])
{
    global $CI;
    static $loaded = [];
    $langFile = explode('.', $key)[0];

    // just to ensure the database is loaded.
    $CI =& get_instance();

    // this is auto load languages files
    if (!in_array($langFile, $loaded))
    {
        //echo $langFile.' loading...<br>';
        $loaded[] = $langFile;
        // load the common lang files
        $CI->lang->load($langFile, config_item('validLang')['name']);
    }

    $line = $CI->lang->line($key);

    if (!is_array($replace) && $replace != '')
    {
        $line = str_ireplace('$1', $replace, $line);
    }
    else if (is_array($replace) && count($replace) > 0)
    {
        foreach ($replace as $k => $value)
        {
            $tmp_num = $k+1;
            $line = str_ireplace("$$tmp_num", $value, $line);
        }
    }

    if (!empty($key))
    {
        if ($echo)
            echo $line;
        else
            return $line;
    }
}

function copyFolder($srcFolder, $disFolder, $copyFolders = false)
{
    if (!is_dir($srcFolder) or !is_dir($disFolder))
        return false;

    $srcFolder = rtrim(str_ireplace('\\', '/', $srcFolder), '/');
    $disFolder = rtrim(str_ireplace('\\', '/', $disFolder), '/');

    $files = scandir($srcFolder);
    $done = true;

    foreach ($files as $k => $item)
    {
        $path = $srcFolder.'/'.$item;
        if ($item != '.' && $item != '..'){

            if (is_file($path))
                copy($path, $disFolder.'/'.$item);
            else if ($copyFolders && is_dir($path))
            {
                mkdir($disFolder.'/'.$item);
                if (!copyFolder($path, $disFolder.'/'.$item, true))
                    return false;
            }
            else
                return false;
        }
    }
    return $done;
}

function deleteFolder($srcFolder, $deleteFolders = false, $deleteRootFolder = true)
{
    if (!is_dir($srcFolder))
        return false;

    $srcFolder = rtrim(str_ireplace('\\', '/', $srcFolder), '/');

    $files = scandir($srcFolder);
    $done = true;

    foreach ($files as $k => $item)
    {
        $path = $srcFolder.'/'.$item;
        if ($item != '.' && $item != '..'){

            if (is_file($path))
                unlink($path);
            else if ($deleteFolders && is_dir($path))
            {
                if (!deleteFolder($path, true))
                    return false;
            }
            else
                return false;
        }
    }
    if ($done && $deleteRootFolder)
        rmdir($srcFolder);
    return $done;
}

function recaptcha ()
{
	global $CI;

    if (get_config_item('recaptcha_status') == 1)
    {
        $secret = get_config_item('secret_key');
        $response = $CI->input->post('g-recaptcha-response',TRUE);
        $remoteip = $CI->input->ip_address();

        $r = @file_get_contents("https://www.google.com/recaptcha/api/siteverify?secret=$secret&response=$response&remoteip=$remoteip");

        $result = @json_decode($r);

        if (@$result->success == 1){return TRUE;}
        else{return FALSE;}
    }
    else
    {
        return TRUE;
    }

}

function is_valid_slug_format($slug)
{
    if (preg_match("/^[a-zA-Z0-9_-]+$/i", $slug))
        return true;
    return false;
}

function is_available_slug($slug)
{
    global $CI;
    $CI =& get_instance();

    if ($CI->db->where('slug', $slug)->get('links')->num_rows())
        return false;
    return true;
}

function is_url ($url)
{
    $pattren = "/^(https|http)?:\/\/([a-z0-9-.]+)\.([a-z0-9]+)(.*)$/i";

    return (boolean) preg_match($pattren,$url);
}

function get_datetime_from_now($duration, $format='Y-m-d H:i:s')
{
    return (new Datetime())->sub(new Dateinterval($duration))->format($format);
}

function get_theme_configs()
{
    global $CI;
    $CI =& get_instance();

    $theme_configs = [];
    $configs = $CI->db->where("option_name LIKE 'theme_%'")->get('settings')->result();

    foreach ($configs as $config)
    {
        $theme_configs[$config->option_name] = $config->option_value;
    }

    return json_decode(json_encode($theme_configs));
}

function current_user()
{
    global $CI;
    $CI =& get_instance();

    $admintoken = $CI->session->admin_token;

    $user = $CI->db->where([
        'user_status'   => 1,
        'user_token'    => $admintoken,
        'user_verified' => 1
    ])->get('users')->first_row();

    if ($user)
        return $user;

    return null;
}

function get_user($id)
{
    global $CI;
    $CI =& get_instance();

    return $CI->db->where('id', intval($id))->get('users')->first_row();
}

function is_admin($user)
{
    if (isset($user->user_status) && intval($user->user_status) == 1)
        return true;
    return false;
}

function round_balance($balance, $num=4)
{
    return round((float)$balance, $num);
}

function get_all_domains()
{
    $CI =& get_instance();
    static $domains = [];

    if (!$domains)
    {
        // Add the main domain.
        if (intval(get_config_item('main_domain_protection')) == 0)
            $domains[] = get_config_item('main_domain');

        $tmp_domains = $CI->db->where('status', 1)->get('domains')->result();

        foreach ($tmp_domains as $key => $domain)
        {
            $domains[] = $domain->domain_name;
        }
    }

    return $domains;
}

function get_domains($index = 0)
{
    $domains = get_all_domains();
    $default_url = base_url();

    $parsed_url = parse_url($default_url);

    if (count($domains) && isset($domains[$index]) && trim($domains[$index]) != '')
    {
        return $parsed_url['scheme']."://".$domains[$index].$parsed_url['path'];
    }
    else
    {
        return $default_url;
    }
}

function is_domain($domain)
{
    return preg_match("/^[a-z0-9-]*\.?[a-z0-9-]+\.[a-z]+$/i", $domain)? true : false;
}

function is_in_packages($domain)
{
    $domains = get_all_domains();
    $default_url = base_url();
    $parsed_url = parse_url($default_url);

    foreach ($domains as $key => $domain)
    {
        if (strtolower($parsed_url['host']) == strtolower($domain))
        {
            return True;
        }
    }

    return False;
}

// don't use the main domain for URL shortening
function main_domain_protection_shield()
{
    $domains = get_all_domains();
    $default_url = base_url();
    $parsed_url = parse_url($default_url);
    $current_domain = $parsed_url['host'];

    if (is_main_domain($current_domain) && intval(get_config_item('main_domain_protection')) == 1)
    {
        return show_my_404();
    }
}

function deny_package_domains()
{
    $domains = get_all_domains();
    $default_url = base_url();
    $parsed_url = parse_url($default_url);
    $current_domain = $parsed_url['host'];

    if (!is_main_domain($current_domain) && is_in_packages($current_domain) && !is_go_page()) # && !go page
    {
        // deny
        header("HTTP/1.1 403 Forbiden!");
        echo "<h1>403 Forbiden!</h1>";
        die();
    }
}


function get_main_domain()
{
    static $main_domain = '';
    if ($main_domain == '')
        $main_domain = get_config_item('main_domain');
    return $main_domain;
}

function is_main_domain($domain)
{
    $parts = explode(":", get_main_domain());
    if ($domain == get_main_domain() or $domain == $parts[0])
        return true;
    return false;
}

function is_go_page()
{
    // include routes
    $route = [];
    require APPPATH."config/routes.php";
    $uri = uri_string();

    foreach ($route as $pattern => $controller)
    {
        if (preg_match("/^".str_replace('/', '\/', $pattern)."/", $uri))
        {
            if (preg_match('/^go/', $controller) or preg_match('/^ajax/', $controller) or preg_match('/^api/', $controller) or preg_match('/^theme/', $controller))
            {
                return true;
            }

            return false;
        }
    }

    return false;
}

function get_default_lang()
{
    $lang_id = intval(config_item('default_language'));
    return get_lang_by_id($lang_id);
}

function get_langs()
{
    $CI =& get_instance();
    return $CI->db->select('*')->where('active', 1)->get('languages')->result_array();
}

function get_lang_by_id($id)
{
    $id = intval($id);

    foreach (get_langs() as $k => $lang)
    {
        if ($id == $lang['id'])
            return $lang;
    }
}

function encode($url, $url_safe = false) {
    return $url; // no need to encode for now
}

function decode($url, $url_safe = false) {
    return $url; // no need to decode for now
}

function is_forbiden_url($url)
{
    $url = preg_replace("/(https|http)?(:\/\/)(www.)?/i", '', $url);
    $bad_urls = explode("\r\n", get_config_item('bad_urls'));

    if (count($bad_urls) == 0 or $bad_urls[0] == '')
        return false;

    foreach ($bad_urls as $k => $u)
    {
        if (preg_match("/^(".$u.")/i", $url))
        {
            return true;
        }
    }
    return false;
}

function get_config_item($option_name)
{
    global $CI;
    static $config = [];

    // just to ensure the database is loaded.
    $CI =& get_instance();

    if (!isset($config[$option_name]))
    {
        foreach($CI->db->get('settings')->result_array() as $k => $row) {
            $config[$row['option_name']] = $row['option_value'];
        }
    }

    return $config[$option_name];
}

function set_config_item($option_name, $option_value)
{
    global $CI;
    static $config = [];

    // just to ensure the database is loaded.
    $CI =& get_instance();

    $CI->db->where(['option_name' => $option_name])->update(_t('settings'), [
        'option_value' => $option_value
    ]);
}

function get_ad ($type='',$in_account=FALSE)
{
    return null;
    $type = ($type == '')? 'ad_autosize' : $type ;

    if (config_item('ads_status') == 1)
    {
        if ((bool)$in_account)
        {
            if (config_item('ads_status_on_accounts') == 1)
            {
                return get_config_item($type);
            }
            else
            {
                return '';
            }
        }
        else
        {
            return get_config_item($type);
        }
    }
    else
    {
        return '';
    }
}

function get_email_tpl($path)
{
    return file_get_contents(str_ireplace('\\', '/', APPPATH.'language/'.config_item('validLang')['name']."/email_tpls/{$path}.html"));
}

function email_tpls_load_and_replace($tpl_path, $consts, $load_header_footer = FALSE)
{
    $template = '';
    $default_consts = array(
            "SITE_NAME" => config_item('sitename'),
            "SITE_URL" => base_url(),
            "CONTACT_URL" => base_url('p/contact')
        );

    if (is_array($consts))
        $default_consts = array_merge($default_consts, $consts);

    if ($load_header_footer)
    {
        $template .= get_email_tpl('header');
        $template .= get_email_tpl($tpl_path);
        $template .= get_email_tpl('footer');
    }
    else
        $template .= get_email_tpl($tpl_path);

    foreach ($default_consts as $k => $v)
    {
        $template = str_replace("{".$k."}", $v, $template);
    }

    return $template;
}

function sendEmail($to, $subject, $msg, $from = array(), $priority=3, $mailtype='html')
{
    if (is_demo())
        return true;

    $mail = new PHPMailer\PHPMailer\PHPMailer();
    $mail->CharSet = 'UTF-8';

    try {

        if (get_config_item('email_method') == 'smtp')
        {
            $mail->IsSMTP();
            $mail->Host = get_config_item('SMTP_Host');
            $mail->Port = get_config_item('SMTP_Port');
            $mail->Username = get_config_item('SMTP_User');
            $mail->Password = get_config_item('SMTP_Pass');
            $mail->SMTPAuth = TRUE;
            $mail->SMTPSecure = get_config_item('mail_encription'); // ssl or tls
            $mail->SMTPAutoTLS = false;

            if (get_config_item('allow_SSL_Insecure_mode') == 1)
            {
                $mail->SMTPOptions = array(
                        'ssl' => [
                            'verify_peer'       => false,
                            'verify_peer_name'  => false,
                            'allow_self_signed' => true
                        ]
                    );
            }

        }
        else
        {
            $mail->IsSendmail();
        }

        if(count($from) == 0)
            $mail->SetFrom(get_config_item('email_from'), config_item('sitename'));
        else
            $mail->SetFrom($from[0], $from[1]);


        if ($mailtype == 'html')
        {
            $mail->IsHTML(TRUE);
            $mail->Body = $msg;
        }
        else
        {
            $mail->IsHTML(FALSE);
            $mail->AltBody = $msg;
        }

        $mail->AddAddress($to);

        $mail->Subject = $subject;

        try {
            return $mail->Send();
        } catch (\Exception $e) {
            return false;
        }

    } catch (PHPMailer\PHPMailer\Exception $e) {
        return false;
    }
}


function pagination($all_items,$num_per_page,$url,$lg='en')
{
    global $CI;
    $CI->load->library('pagination');
    $lg = (strtolower(config_item('validLang')['symbol']) == 'en' or strtolower(config_item('validLang')['symbol']) == 'ar') ? strtolower(config_item('validLang')['symbol']) : 'en' ;

    $lang = array();
    $lang['en']['next'] = '<span dir="rtl"><i class="fa fa-angle-right"></i> next</span>';
    $lang['ar']['next'] = '<span dir="ltr"><i class="fa fa-angle-left"></i> التالي<span>';
    $lang['en']['prev'] = '<span dir="ltr"><i class="fa fa-angle-left"></i> prev</span>';
    $lang['ar']['prev'] = '<span dir="rtl"><i class="fa fa-angle-right"></i> السابق</span>';
    $lang['en']['first'] = '<span dir="ltr">first</span>';
    $lang['ar']['first'] = '<span dir="ltr">الصفحة الأولى</span>';
    $lang['en']['last'] = '<span dir="ltr">last</span>';
    $lang['ar']['last'] = '<span dir="ltr">الصفحة الأخيرة</span>';

    $config['base_url'] = $url;
    $config['total_rows'] = $all_items;
    $config['per_page'] = $num_per_page;
    $config['use_page_numbers'] = TRUE;
    $config['reuse_query_string'] = TRUE;
    $config['num_links'] = 2;

    $config['full_tag_open'] = "<nav><ul class='pagination'>";
    $config['full_tag_close'] = "</ul></nav>";

    $config['num_tag_open'] = "<li>";
    $config['num_tag_close'] = "</li>";

    $config['cur_tag_open'] = "<li class='active'><a href='#'>";
    $config['cur_tag_close'] = "</a></li>";

    $config['next_link'] = $lang[$lg]['next'];
    $config['next_tag_open'] = "<li>";
    $config['next_tag_close'] = "</li>";

    $config['prev_link'] = $lang[$lg]['prev'];
    $config['prev_tag_open'] = "<li>";
    $config['prev_tag_close'] = "</li>";

    $config['last_link'] = $lang[$lg]['last'];
    $config['last_tag_open'] = "<li>";
    $config['last_tag_close'] = "</li>";

    $config['first_link'] = $lang[$lg]['first'];
    $config['first_tag_open'] = "<li>";
    $config['first_tag_close'] = "</li>";

    $CI->pagination->initialize($config);
    return $CI->pagination->create_links();
}

function get_logo ($height=NULL)
{
    if (config_item('show_logo') == 1)
    {
        $height = ($height != NULL && is_int($height))? "style='height: ".$height."px;'": '' ;
        $s = "<img src='".base_url()."assets/img/logo.png?v=".rand(1, 9999999)."' alt='".config_item('sitename')."' title='".config_item('sitename')."' ".$height." >";
    }
    else
    {
        $s = config_item('sitename');
    }
    return $s;
}

function get_icon ()
{
    return  "
            <link rel='apple-touch-icon' sizes='72x72' href='".base_url()."assets/img/favicon.png?m=".uniqid()."'>
            <link rel='icon' type='image/png' sizes='32x32' href='".base_url()."assets/img/favicon.png?m=".uniqid()."'>
        ";
}

function get_profile_img ($user_token)
{
    $path = "uploads/users/profile-images/".md5($user_token).".png";

    if (file_exists($path))
    {
        $src = base_url().$path.'?v='.rand(1, 99999);
    }
    else
    {
        $src = base_url()."/uploads/users/profile-images/default-boy.png";
    }

    return $src;
}

function delete_profile_img ($user_token)
{
    $path = "uploads/users/profile-images/".md5($user_token).".png";

    if (file_exists($path))
    {
        $u = (@unlink($path))? TRUE : FALSE ;
        return $u;
    }
    else
    {
        return false;
    }
}

function color()
{
    $colors = array(
            "#023047",
            "#ffb703",
            "#22223b",
            "#4a4e69",
            "#6a994e",
            "#a7c957",
            "#d62828",
            "#7209b7",
            "#3a0ca3",
            "#606c38",
            "#343a40",
            "#6b705c",
            "#2ec4b6",
            "#735d78",
            "#006d77"
        );

    return $colors[array_rand($colors, 1)];
}

function get_country_menu ($name='',$class='',$select=0,$l='')
{
    $lang = config_item('validLang')['symbol'];
    $country = array();
    $country['ar'] = array(
        "اختر بلدك",
        "أفغانستان",
        "ألبانيا",
        "الجزائر",
        "أندورا",
        "أنغولا",
        "أنتيغوا وبربودا",
        "الأرجنتين",
        "أرمينيا",
        "أستراليا",
        "النمسا",
        "أذربيجان",
        "الباهاما",
        "البحرين",
        "بنغلاديش",
        "بربادوس",
        "روسيا البيضاء",
        "بلجيكا",
        "بليز",
        "بنين",
        "بوتان",
        "بوليفيا",
        "البوسنة والهرسك",
        "بوتسوانا",
        "البرازيل",
        "بروناي",
        "بلغاريا",
        "بوركينا فاسو",
        "بوروندي",
        "كمبوديا",
        "الكاميرون",
        "كندا",
        "الرأس الأخضر",
        "جمهورية افريقيا الوسطى",
        "تشاد",
        "شيلي",
        "الصين",
        "كولومبيا",
        "جزر القمر",
        "الكونغو (برازافيل)",
        "الكونغو",
        "كوستا ريكا",
        "كوت ديفوار",
        "كرواتيا",
        "كوبا",
        "قبرص",
        "جمهورية التشيك",
        "الدنمارك",
        "جيبوتي",
        "دومينيكا",
        "جمهورية الدومنيكان",
        "تيمور الشرقية (تيمور تيمورلنك)",
        "الاكوادور",
        "مصر",
        "السلفادور",
        "غينيا الإستوائية",
        "إريتريا",
        "استونيا",
        "أثيوبيا",
        "فيجي",
        "فنلندا",
        "فرنسا",
        "الغابون",
        "غامبيا",
        "جورجيا",
        "ألمانيا",
        "غانا",
        "اليونان",
        "غرينادا",
        "غواتيمالا",
        "غينيا",
        "غينيا بيساو",
        "غيانا",
        "هايتي",
        "هندوراس",
        "هنغاريا",
        "أيسلندا",
        "الهند",
        "أندونيسيا",
        "إيران",
        "العراق",
        "ايرلندا",
        "إيطاليا",
        "جامايكا",
        "اليابان",
        "الأردن",
        "كازاخستان",
        "كينيا",
        "كيريباس",
        "كوريا الشمالية",
        "كوريا، جنوب",
        "الكويت",
        "قيرغيزستان",
        "لاوس",
        "لاتفيا",
        "لبنان",
        "ليسوتو",
        "ليبيريا",
        "ليبيا",
        "ليختنشتاين",
        "ليتوانيا",
        "لوكسمبورغ",
        "مقدونيا",
        "مدغشقر",
        "ملاوي",
        "ماليزيا",
        "جزر المالديف",
        "مالي",
        "مالطا",
        "جزر مارشال",
        "موريتانيا",
        "موريشيوس",
        "المكسيك",
        "ميكرونيزيا",
        "مولدافيا",
        "موناكو",
        "منغوليا",
        "المغرب",
        "موزمبيق",
        "ميانمار",
        "ناميبيا",
        "ناورو",
        "نيبال",
        "هولندا",
        "نيوزيلاندا",
        "نيكاراغوا",
        "النيجر",
        "نيجيريا",
        "النرويج",
        "سلطنة عمان",
        "باكستان",
        "بالاو",
        "بنما",
        "بابوا غينيا الجديدة",
        "باراغواي",
        "بيرو",
        "الفلبين",
        "بولندا",
        "البرتغال",
        "قطر",
        "رومانيا",
        "روسيا",
        "رواندا",
        "سانت كيتس ونيفيس",
        "سانت لوسيا",
        "سانت فنسنت",
        "ساموا",
        "سان مارينو",
        "ساو تومي وبرينسيبي",
        "المملكة العربية السعودية",
        "السنغال",
        "صربيا والجبل الأسود",
        "سيشيل",
        "سيرا ليون",
        "سنغافورة",
        "سلوفاكيا",
        "سلوفينيا",
        "جزر سليمان",
        "الصومال",
        "جنوب أفريقيا",
        "إسبانيا",
        "سيريلانكا",
        "السودان",
        "سورينام",
        "سوازيلاند",
        "السويد",
        "سويسرا",
        "سوريا",
        "تايوان",
        "طاجيكستان",
        "تنزانيا",
        "تايلاند",
        "توغو",
        "تونغا",
        "ترينداد وتوباغو",
        "تونس",
        "ديك رومي",
        "تركمانستان",
        "توفالو",
        "أوغندا",
        "أوكرانيا",
        "الإمارات العربية المتحدة",
        "المملكة المتحدة",
        "الولايات المتحدة",
        "أوروغواي",
        "أوزبكستان",
        "فانواتو",
        "مدينة الفاتيكان",
        "فنزويلا",
        "فيتنام",
        "اليمن",
        "زامبيا",
        "زيمبابوي"
    );
    $country['en'] = array(
        "Choose your country",
        "Afghanistan",
        "Albania",
        "Algeria",
        "Andorra",
        "Angola",
        "Antigua and Barbuda",
        "Argentina",
        "Armenia",
        "Australia",
        "Austria",
        "Azerbaijan",
        "Bahamas",
        "Bahrain",
        "Bangladesh",
        "Barbados",
        "Belarus",
        "Belgium",
        "Belize",
        "Benin",
        "Bhutan",
        "Bolivia",
        "Bosnia and Herzegovina",
        "Botswana",
        "Brazil",
        "Brunei",
        "Bulgaria",
        "Burkina Faso",
        "Burundi",
        "Cambodia",
        "Cameroon",
        "Canada",
        "Cape Verde",
        "Central African Republic",
        "Chad",
        "Chile",
        "China",
        "colombia",
        "Comoros",
        "Congo (Brazzaville)",
        "Congo",
        "Costa Rica",
        "Cote d'Ivoire",
        "Croatia",
        "Cuba",
        "Cyprus",
        "Czech Republic",
        "Denmark",
        "Djibouti",
        "Dominica",
        "Dominican Republic",
        "East Timor (Timor Timur)",
        "Ecuador",
        "Egypt",
        "El Salvador",
        "Equatorial Guinea",
        "Eritrea",
        "Estonia",
        "Ethiopia",
        "Fiji",
        "Finland",
        "France",
        "Gabon",
        "Gambia, The",
        "Georgia",
        "Germany",
        "Ghana",
        "Greece",
        "Grenada",
        "Guatemala",
        "Guinea",
        "Guinea-Bissau",
        "Guyana",
        "Haiti",
        "Honduras",
        "Hungary",
        "Iceland",
        "India",
        "Indonesia",
        "Iran",
        "Iraq",
        "Ireland",
        "Italy",
        "Jamaica",
        "Japan",
        "Jordan",
        "Kazakhstan",
        "Kenya",
        "Kiribati",
        "Korea, North",
        "Korea, South",
        "Kuwait",
        "Kyrgyzstan",
        "Laos",
        "Latvia",
        "Lebanon",
        "Lesotho",
        "Liberia",
        "Libya",
        "Liechtenstein",
        "Lithuania",
        "Luxembourg",
        "Macedonia",
        "Madagascar",
        "Malawi",
        "Malaysia",
        "Maldives",
        "Mali",
        "Malta",
        "Marshall Islands",
        "Mauritania",
        "Mauritius",
        "Mexico",
        "Micronesia",
        "Moldova",
        "Monaco",
        "Mongolia",
        "Morocco",
        "Mozambique",
        "Myanmar",
        "Namibia",
        "Nauru",
        "Nepal",
        "Netherlands",
        "New Zealand",
        "Nicaragua",
        "Niger",
        "Nigeria",
        "Norway",
        "Oman",
        "Pakistan",
        "Palau",
        "Panama",
        "Papua New Guinea",
        "Paraguay",
        "Peru",
        "Philippines",
        "Poland",
        "Portugal",
        "Qatar",
        "Romania",
        "Russia",
        "Rwanda",
        "Saint Kitts and Nevis",
        "Saint Lucia",
        "Saint Vincent",
        "Samoa",
        "San Marino",
        "Sao Tome and Principe",
        "Saudi Arabia",
        "Senegal",
        "Serbia and Montenegro",
        "Seychelles",
        "Sierra Leone",
        "Singapore",
        "Slovakia",
        "Slovenia",
        "Solomon Islands",
        "Somalia",
        "South Africa",
        "Spain",
        "Sri Lanka",
        "Sudan",
        "Suriname",
        "Swaziland",
        "Sweden",
        "Switzerland",
        "Syria",
        "Taiwan",
        "Tajikistan",
        "Tanzania",
        "Thailand",
        "Togo",
        "Tonga",
        "Trinidad and Tobago",
        "Tunisia",
        "Turkey",
        "Turkmenistan",
        "Tuvalu",
        "Uganda",
        "Ukraine",
        "United Arab Emirates",
        "United Kingdom",
        "United States",
        "Uruguay",
        "Uzbekistan",
        "Vanuatu",
        "Vatican City",
        "Venezuela",
        "Vietnam",
        "Yemen",
        "Zambia",
        "Zimbabwe"
    );

    $lang = (isset($country[$lang]))? $lang : 'en' ;

    $select = ($select == '')? 0 : $select ;
    $dir = ($lang == 'en')? 'ltr' : 'rtl' ;
    $s = "<div dir='".$dir."'><select ";

    if ($name != '')
    {
        $s .= "name='".$name."' ";
    }

    if ($class != '')
    {
        $s .= "class='".$class."' >";
    }

    foreach ($country[$lang] as $k => $v)
    {
        if ($select == $k)
        {
            $s .= "<option value='".$k."' selected >".$v."</option>";
        }
        else
        {
            $s .= "<option value='".$k."' >".$v."</option>";
        }
    }
    $s .= "</select></div>";
    return $s;
}

function get_timezone_menu ($name='',$class='',$select='')
{
    $timezones = array (
    '(GMT-11:00) Midway Island' => 'Pacific/Midway',
    '(GMT-11:00) Samoa' => 'Pacific/Samoa',
    '(GMT-10:00) Hawaii' => 'Pacific/Honolulu',
    '(GMT-09:00) Alaska' => 'US/Alaska',
    '(GMT-08:00) Pacific Time (US &amp; Canada)' => 'America/Los_Angeles',
    '(GMT-08:00) Tijuana' => 'America/Tijuana',
    '(GMT-07:00) Arizona' => 'US/Arizona',
    '(GMT-07:00) Chihuahua' => 'America/Chihuahua',
    '(GMT-07:00) La Paz' => 'America/Chihuahua',
    '(GMT-07:00) Mazatlan' => 'America/Mazatlan',
    '(GMT-07:00) Mountain Time (US &amp; Canada)' => 'US/Mountain',
    '(GMT-06:00) Central America' => 'America/Managua',
    '(GMT-06:00) Central Time (US &amp; Canada)' => 'US/Central',
    '(GMT-06:00) Guadalajara' => 'America/Mexico_City',
    '(GMT-06:00) Mexico City' => 'America/Mexico_City',
    '(GMT-06:00) Monterrey' => 'America/Monterrey',
    '(GMT-06:00) Saskatchewan' => 'Canada/Saskatchewan',
    '(GMT-05:00) Bogota' => 'America/Bogota',
    '(GMT-05:00) Eastern Time (US &amp; Canada)' => 'US/Eastern',
    '(GMT-05:00) Indiana (East)' => 'US/East-Indiana',
    '(GMT-05:00) Lima' => 'America/Lima',
    '(GMT-05:00) Quito' => 'America/Bogota',
    '(GMT-04:00) Atlantic Time (Canada)' => 'Canada/Atlantic',
    '(GMT-04:30) Caracas' => 'America/Caracas',
    '(GMT-04:00) La Paz' => 'America/La_Paz',
    '(GMT-04:00) Santiago' => 'America/Santiago',
    '(GMT-03:30) Newfoundland' => 'Canada/Newfoundland',
    '(GMT-03:00) Brasilia' => 'America/Sao_Paulo',
    '(GMT-03:00) Buenos Aires' => 'America/Argentina/Buenos_Aires',
    '(GMT-03:00) Georgetown' => 'America/Argentina/Buenos_Aires',
    '(GMT-03:00) Greenland' => 'America/Godthab',
    '(GMT-02:00) Mid-Atlantic' => 'America/Noronha',
    '(GMT-01:00) Azores' => 'Atlantic/Azores',
    '(GMT-01:00) Cape Verde Is.' => 'Atlantic/Cape_Verde',
    '(GMT+00:00) Casablanca' => 'Africa/Casablanca',
    '(GMT+00:00) Edinburgh' => 'Europe/London',
    '(GMT+00:00) Greenwich Mean Time : Dublin' => 'Etc/Greenwich',
    '(GMT+00:00) Lisbon' => 'Europe/Lisbon',
    '(GMT+00:00) London' => 'Europe/London',
    '(GMT+00:00) Monrovia' => 'Africa/Monrovia',
    '(GMT+00:00) UTC' => 'UTC',
    '(GMT+01:00) Amsterdam' => 'Europe/Amsterdam',
    '(GMT+01:00) Belgrade' => 'Europe/Belgrade',
    '(GMT+01:00) Berlin' => 'Europe/Berlin',
    '(GMT+01:00) Bern' => 'Europe/Berlin',
    '(GMT+01:00) Bratislava' => 'Europe/Bratislava',
    '(GMT+01:00) Brussels' => 'Europe/Brussels',
    '(GMT+01:00) Budapest' => 'Europe/Budapest',
    '(GMT+01:00) Copenhagen' => 'Europe/Copenhagen',
    '(GMT+01:00) Ljubljana' => 'Europe/Ljubljana',
    '(GMT+01:00) Madrid' => 'Europe/Madrid',
    '(GMT+01:00) Paris' => 'Europe/Paris',
    '(GMT+01:00) Prague' => 'Europe/Prague',
    '(GMT+01:00) Rome' => 'Europe/Rome',
    '(GMT+01:00) Sarajevo' => 'Europe/Sarajevo',
    '(GMT+01:00) Skopje' => 'Europe/Skopje',
    '(GMT+01:00) Stockholm' => 'Europe/Stockholm',
    '(GMT+01:00) Vienna' => 'Europe/Vienna',
    '(GMT+01:00) Warsaw' => 'Europe/Warsaw',
    '(GMT+01:00) West Central Africa' => 'Africa/Lagos',
    '(GMT+01:00) Zagreb' => 'Europe/Zagreb',
    '(GMT+02:00) Athens' => 'Europe/Athens',
    '(GMT+02:00) Bucharest' => 'Europe/Bucharest',
    '(GMT+02:00) Cairo' => 'Africa/Cairo',
    '(GMT+02:00) Harare' => 'Africa/Harare',
    '(GMT+02:00) Helsinki' => 'Europe/Helsinki',
    '(GMT+02:00) Istanbul' => 'Europe/Istanbul',
    '(GMT+02:00) Jerusalem' => 'Asia/Jerusalem',
    '(GMT+02:00) Kyiv' => 'Europe/Helsinki',
    '(GMT+02:00) Pretoria' => 'Africa/Johannesburg',
    '(GMT+02:00) Riga' => 'Europe/Riga',
    '(GMT+02:00) Sofia' => 'Europe/Sofia',
    '(GMT+02:00) Tallinn' => 'Europe/Tallinn',
    '(GMT+02:00) Vilnius' => 'Europe/Vilnius',
    '(GMT+03:00) Baghdad' => 'Asia/Baghdad',
    '(GMT+03:00) Kuwait' => 'Asia/Kuwait',
    '(GMT+03:00) Minsk' => 'Europe/Minsk',
    '(GMT+03:00) Nairobi' => 'Africa/Nairobi',
    '(GMT+03:00) Riyadh' => 'Asia/Riyadh',
    '(GMT+03:00) Volgograd' => 'Europe/Volgograd',
    '(GMT+03:30) Tehran' => 'Asia/Tehran',
    '(GMT+04:00) Abu Dhabi' => 'Asia/Muscat',
    '(GMT+04:00) Baku' => 'Asia/Baku',
    '(GMT+04:00) Moscow' => 'Europe/Moscow',
    '(GMT+04:00) Muscat' => 'Asia/Muscat',
    '(GMT+04:00) St. Petersburg' => 'Europe/Moscow',
    '(GMT+04:00) Tbilisi' => 'Asia/Tbilisi',
    '(GMT+04:00) Yerevan' => 'Asia/Yerevan',
    '(GMT+04:30) Kabul' => 'Asia/Kabul',
    '(GMT+05:00) Islamabad' => 'Asia/Karachi',
    '(GMT+05:00) Karachi' => 'Asia/Karachi',
    '(GMT+05:00) Tashkent' => 'Asia/Tashkent',
    '(GMT+05:30) Chennai' => 'Asia/Calcutta',
    '(GMT+05:30) Kolkata' => 'Asia/Kolkata',
    '(GMT+05:30) Mumbai' => 'Asia/Calcutta',
    '(GMT+05:30) New Delhi' => 'Asia/Calcutta',
    '(GMT+05:30) Sri Jayawardenepura' => 'Asia/Calcutta',
    '(GMT+05:45) Kathmandu' => 'Asia/Katmandu',
    '(GMT+06:00) Almaty' => 'Asia/Almaty',
    '(GMT+06:00) Astana' => 'Asia/Dhaka',
    '(GMT+06:00) Dhaka' => 'Asia/Dhaka',
    '(GMT+06:00) Ekaterinburg' => 'Asia/Yekaterinburg',
    '(GMT+06:30) Rangoon' => 'Asia/Rangoon',
    '(GMT+07:00) Bangkok' => 'Asia/Bangkok',
    '(GMT+07:00) Hanoi' => 'Asia/Bangkok',
    '(GMT+07:00) Jakarta' => 'Asia/Jakarta',
    '(GMT+07:00) Novosibirsk' => 'Asia/Novosibirsk',
    '(GMT+08:00) Beijing' => 'Asia/Hong_Kong',
    '(GMT+08:00) Chongqing' => 'Asia/Chongqing',
    '(GMT+08:00) Hong Kong' => 'Asia/Hong_Kong',
    '(GMT+08:00) Krasnoyarsk' => 'Asia/Krasnoyarsk',
    '(GMT+08:00) Kuala Lumpur' => 'Asia/Kuala_Lumpur',
    '(GMT+08:00) Perth' => 'Australia/Perth',
    '(GMT+08:00) Singapore' => 'Asia/Singapore',
    '(GMT+08:00) Taipei' => 'Asia/Taipei',
    '(GMT+08:00) Ulaan Bataar' => 'Asia/Ulan_Bator',
    '(GMT+08:00) Urumqi' => 'Asia/Urumqi',
    '(GMT+09:00) Irkutsk' => 'Asia/Irkutsk',
    '(GMT+09:00) Osaka' => 'Asia/Tokyo',
    '(GMT+09:00) Sapporo' => 'Asia/Tokyo',
    '(GMT+09:00) Seoul' => 'Asia/Seoul',
    '(GMT+09:00) Tokyo' => 'Asia/Tokyo',
    '(GMT+09:30) Adelaide' => 'Australia/Adelaide',
    '(GMT+09:30) Darwin' => 'Australia/Darwin',
    '(GMT+10:00) Brisbane' => 'Australia/Brisbane',
    '(GMT+10:00) Canberra' => 'Australia/Canberra',
    '(GMT+10:00) Guam' => 'Pacific/Guam',
    '(GMT+10:00) Hobart' => 'Australia/Hobart',
    '(GMT+10:00) Melbourne' => 'Australia/Melbourne',
    '(GMT+10:00) Port Moresby' => 'Pacific/Port_Moresby',
    '(GMT+10:00) Sydney' => 'Australia/Sydney',
    '(GMT+10:00) Yakutsk' => 'Asia/Yakutsk',
    '(GMT+11:00) Vladivostok' => 'Asia/Vladivostok',
    '(GMT+12:00) Auckland' => 'Pacific/Auckland',
    '(GMT+12:00) Fiji' => 'Pacific/Fiji',
    '(GMT+12:00) International Date Line West' => 'Pacific/Kwajalein',
    '(GMT+12:00) Kamchatka' => 'Asia/Kamchatka',
    '(GMT+12:00) Magadan' => 'Asia/Magadan',
    '(GMT+12:00) Marshall Is.' => 'Pacific/Fiji',
    '(GMT+12:00) New Caledonia' => 'Asia/Magadan',
    '(GMT+12:00) Solomon Is.' => 'Asia/Magadan',
    '(GMT+12:00) Wellington' => 'Pacific/Auckland',
    '(GMT+13:00) Nuku\'alofa' => 'Pacific/Tongatapu'
    );

    $select = ($select == '')? 'Africa/Casablanca' : $select ;
    $s = "<select ";

    if ($name != '')
    {
        $s .= "name='".$name."' ";
    }

    if ($class != '')
    {
        $s .= "class='".$class."' >";
    }

    foreach ($timezones as $k => $v)
    {
        if ($select == $v)
        {
            $s .= "<option value='".$v."' selected >".$k."</option>";
        }
        else
        {
            $s .= "<option value='".$v."' >".$k."</option>";
        }
    }
    $s .= "</select>";
    return $s;
}


/*============================= private function for type of the website ======================================*/

function get_slug ()
{
    global $CI;

    $number = rand(3,6); // number of chars
    $str = "azertyuiopqsdfghjklmwxcvbnAZERTYUIOPQSDFGHJKLMWXCVBN0123456789";
    $slug = substr(str_shuffle($str),rand(0,9),$number);

    $count = $CI->db->where('slug', $slug)->count_all_results('links');

    if ($count)
    {
        return get_slug();
    }

    return $slug;
}

// type must be like 300x250
function get_google_ad ($pub='', $channel='', $type='')
{
    global $CI;
    $result = '';

    if (config_item('ads_status') == 0)
        return;

    if ($type == '')
        $result = get_config_item('ad_autosize');
    else
        $result = get_config_item('ad_'.$type);

    return "<div class='adboxxx'>".$result."</div>";
}


?>

