<?php

declare(strict_types=1);

namespace ADLinker\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

/**
 * Auto-generated Migration: Please modify to your needs!
 */
final class Version20210526104357 extends AbstractMigration
{
    public function getDescription(): string
    {
        $this->site_name      = trim(_addslashes(strip_tags(getenv('SITE_NAME'))));
        $this->support_email  = trim(strtolower(_addslashes(strip_tags(getenv('SITE_CONTACT_US_EMAIL')))));
        $this->sub_folder     = get_sub_folder();
        $this->time           = time();

        $this->admin_name     = trim(_addslashes(strip_tags(getenv('USER_USERNAME'))));
        $this->admin_email    = trim(strtolower(_addslashes(strip_tags(getenv('USER_EMAIL')))));
        $this->admin_pass     = trim(_addslashes(strip_tags(getenv('USER_PASSWORD'))));

        $this->db_prefix      = trim(strtolower(_addslashes(strip_tags(getenv('DB_PREFIX')))));
        $this->db_hostname    = trim(_addslashes(strip_tags(getenv('DB_HOSTNAME'))));
        $this->db_name        = trim(_addslashes(strip_tags(getenv('DB_NAME'))));
        $this->db_username    = trim(_addslashes(strip_tags(getenv('DB_USER'))));
        $this->db_password    = trim(_addslashes(strip_tags(getenv('DB_PASSWORD'))));

        return 'Links & stats';
    }

    public function up(Schema $schema): void
    {
        $sm = $this->connection->getSchemaManager();
        $user = $sm->listTableDetails($this->db_prefix.'users');
        $countries = $sm->listTableDetails($this->db_prefix.'countries');
        $links = $sm->listTableDetails($this->db_prefix.'links');
        // create stats table.
        $stats = $schema->createTable($this->db_prefix.'stats');
        $stats->addColumn('id', 'bigint', [
            'autoincrement' => true
        ]);
        $stats->addColumn('user_id', 'integer');
        $stats->addColumn('link_id', 'integer', ['default' => 0, 'notnull' => false]);
        $stats->addColumn('country_id', 'integer', ['notnull' => false]);
        $stats->addColumn('views', 'integer', ['default' => 0]);
        $stats->addColumn('earnings', 'float', ['default' => 0]);
        $stats->addColumn('browser', 'string', ['default' => 'unknown']);
        $stats->addColumn('device', 'string', ['default' => 'unknown']);
        $stats->addColumn('os', 'string', ['default' => 'unknown']);
        $stats->addColumn('created', 'date');

        $stats->setPrimaryKey(['id']);
        $stats->addForeignKeyConstraint($user, ['user_id'], ['id'], [
            'onUpdate' => 'CASCADE',
            'onDelete' => 'CASCADE',
        ]);
        $stats->addForeignKeyConstraint($countries, ['country_id'], ['id'], [
            'onUpdate' => 'CASCADE',
            'onDelete' => 'SET NULL',
        ]);
        $stats->addForeignKeyConstraint($links, ['link_id'], ['id'], [
            'onUpdate' => 'CASCADE',
            'onDelete' => 'SET NULL',
        ]);
    }

    public function down(Schema $schema): void
    {
        $this->addSql('DROP TABLE IF EXISTS '.$this->db_prefix.'stats');
    }
}
