"use strict"

// Some variables and functions in this file should be global.

// for google charts styling.
const COLORS = ['#4CAF50', '#8BC34A', '#FFC107', '#FF9800', '#FF5722', '#E91E63', '#9C27B0', '#673AB7']

const DefaultOptions = {
	chartArea: { left: '10%', top: '10%', width: "85%", height: "85%"},
	colors: COLORS,
}

/*=========================== Colors Conversions ==============================*/
function hexToHSL(H, raw=false) {
  // Convert hex to RGB first
  let r = 0, g = 0, b = 0;
  if (H.length == 4) {
    r = "0x" + H[1] + H[1];
    g = "0x" + H[2] + H[2];
    b = "0x" + H[3] + H[3];
  } else if (H.length == 7) {
    r = "0x" + H[1] + H[2];
    g = "0x" + H[3] + H[4];
    b = "0x" + H[5] + H[6];
  }
  // Then to HSL
  r /= 255;
  g /= 255;
  b /= 255;
  let cmin = Math.min(r,g,b),
      cmax = Math.max(r,g,b),
      delta = cmax - cmin,
      h = 0,
      s = 0,
      l = 0;

  if (delta == 0)
    h = 0;
  else if (cmax == r)
    h = ((g - b) / delta) % 6;
  else if (cmax == g)
    h = (b - r) / delta + 2;
  else
    h = (r - g) / delta + 4;

  h = Math.round(h * 60);

  if (h < 0)
    h += 360;

  l = (cmax + cmin) / 2;
  s = delta == 0 ? 0 : delta / (1 - Math.abs(2 * l - 1));
  s = +(s * 100).toFixed(1);
  l = +(l * 100).toFixed(1);

  if (raw)
		return h + "," + s + "%," + l + "%"

	return "hsl(" + h + "," + s + "%," + l + "%)"
}

function HSLToHex(h,s,l) {
  s /= 100;
  l /= 100;

  let c = (1 - Math.abs(2 * l - 1)) * s,
      x = c * (1 - Math.abs((h / 60) % 2 - 1)),
      m = l - c/2,
      r = 0,
      g = 0,
      b = 0;

  if (0 <= h && h < 60) {
    r = c; g = x; b = 0;
  } else if (60 <= h && h < 120) {
    r = x; g = c; b = 0;
  } else if (120 <= h && h < 180) {
    r = 0; g = c; b = x;
  } else if (180 <= h && h < 240) {
    r = 0; g = x; b = c;
  } else if (240 <= h && h < 300) {
    r = x; g = 0; b = c;
  } else if (300 <= h && h < 360) {
    r = c; g = 0; b = x;
  }
  // Having obtained RGB, convert channels to hex
  r = Math.round((r + m) * 255).toString(16);
  g = Math.round((g + m) * 255).toString(16);
  b = Math.round((b + m) * 255).toString(16);

  // Prepend 0s, if necessary
  if (r.length == 1)
    r = "0" + r;
  if (g.length == 1)
    g = "0" + g;
  if (b.length == 1)
    b = "0" + b;

  return "#" + r + g + b;
}

//======================= set default values from 'select' ====================
function fillMissing(labels, graphData, format="DD-MM-YYYY")
{
	for (let i = 0; i < labels.length; i++) {
	  //make sure we are not checking the last date in the labels array
	  if (i + 1 < labels.length) {
	    let date1 = moment(labels[i], format);
	    let date2 = moment(labels[i + 1], format);

	    //if the current date +1 is not the same as it's next neighbor we have to add in a new one
	    if (!date1.add(1, "days").isSame(date2)) {

	      //add the label
	      labels.splice(i + 1, 0, date1.format(format));
	      //add the data
	      graphData.splice(i + 1, 0, 0);
	    }
	  }
	}
}

window.addEventListener('load', (e) => {

	//======================= set default values from 'select' ====================
	const selectList = Array.from(document.querySelectorAll("select[data-default]"))
	selectList.map(select => {
		Array.from(select.querySelectorAll('option')).map(opt => {
			if (opt.getAttribute('value') === select.getAttribute('data-default'))
	        	opt.setAttribute("selected", "")
		})
	})

	/*=========================== Duration changes detection ==============================*/
	const select = document.querySelector('#duration')
	if (select)
	{
		select.addEventListener('change', (e) => {
			e.preventDefault()
			location.search = `d=${e.target.value}`
		})
	}

	/*=========================== Enable lc_switch ==============================*/
	lc_switch('input[type=checkbox]:not(.data-bool), input[type=radio]:not(.data-bool)', {
	    on_txt      : 'ON',
	    off_txt     : 'OFF',
	    on_color    : false,
	    // (bool) whether to enable compact mode
	    compact_mode: true
	});

	lc_switch('input[type=checkbox].data-bool, input[type=radio].data-bool', {
	    on_txt      : 'ON',
	    off_txt     : 'OFF',
	    on_color    : false,
	    // (bool) whether to enable compact mode
	    compact_mode: false
	});

  /*=========================== Cookies Alert Policy ==============================*/
  const cookie_agree = document.querySelector(".cookie-agree-button")
  const cookie_alert = document.querySelector(".cookie-alert")

  const current_status = parseInt(localStorage.getItem("cookie-policy"))

  if (current_status !== 1)
  {
      if (cookie_alert)
        cookie_alert.style.display = "flex"
  }

  cookie_agree?.addEventListener("click", () => {
    cookie_alert.style.display = "none"
    localStorage.setItem("cookie-policy", 1)
  })



}) // end onload
